@@ -1,7 +1,7 @@
 """
 Type annotations for imagebuilder service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html)
+[Open documentation](./client.md)
 
 Usage::
 
@@ -17,8 +17,8 @@ from typing import Any, Dict, List, Type
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_imagebuilder.literals import ComponentType, Ownership, PipelineStatus, Platform
-from mypy_boto3_imagebuilder.type_defs import (
+from .literals import ComponentType, Ownership, PipelineStatus, Platform
+from .type_defs import (
     CancelImageCreationResponseTypeDef,
     ComponentConfigurationTypeDef,
     CreateComponentResponseTypeDef,
@@ -117,8 +117,8 @@ class Exceptions:
 
 class ImagebuilderClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client)
+    [Show boto3-stubs documentation](./client.md)
     """
 
     meta: ClientMeta
@@ -126,16 +126,16 @@ class ImagebuilderClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can-paginate)
         """
 
     def cancel_image_creation(
         self, imageBuildVersionArn: str, clientToken: str
     ) -> CancelImageCreationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.cancel_image_creation)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#cancel-image-creation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.cancel_image_creation)
+        [Show boto3-stubs documentation](./client.md#cancel-image-creation)
         """
 
     def create_component(
@@ -153,8 +153,8 @@ class ImagebuilderClient:
         tags: Dict[str, str] = None,
     ) -> CreateComponentResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.create_component)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#create-component)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.create_component)
+        [Show boto3-stubs documentation](./client.md#create-component)
         """
 
     def create_container_recipe(
@@ -177,8 +177,8 @@ class ImagebuilderClient:
         kmsKeyId: str = None,
     ) -> CreateContainerRecipeResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.create_container_recipe)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#create-container-recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.create_container_recipe)
+        [Show boto3-stubs documentation](./client.md#create-container-recipe)
         """
 
     def create_distribution_configuration(
@@ -190,8 +190,8 @@ class ImagebuilderClient:
         tags: Dict[str, str] = None,
     ) -> CreateDistributionConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.create_distribution_configuration)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#create-distribution-configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.create_distribution_configuration)
+        [Show boto3-stubs documentation](./client.md#create-distribution-configuration)
         """
 
     def create_image(
@@ -206,8 +206,8 @@ class ImagebuilderClient:
         tags: Dict[str, str] = None,
     ) -> CreateImageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.create_image)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#create-image)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.create_image)
+        [Show boto3-stubs documentation](./client.md#create-image)
         """
 
     def create_image_pipeline(
@@ -226,8 +226,8 @@ class ImagebuilderClient:
         tags: Dict[str, str] = None,
     ) -> CreateImagePipelineResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.create_image_pipeline)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#create-image-pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.create_image_pipeline)
+        [Show boto3-stubs documentation](./client.md#create-image-pipeline)
         """
 
     def create_image_recipe(
@@ -243,8 +243,8 @@ class ImagebuilderClient:
         workingDirectory: str = None,
     ) -> CreateImageRecipeResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.create_image_recipe)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#create-image-recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.create_image_recipe)
+        [Show boto3-stubs documentation](./client.md#create-image-recipe)
         """
 
     def create_infrastructure_configuration(
@@ -264,56 +264,56 @@ class ImagebuilderClient:
         tags: Dict[str, str] = None,
     ) -> CreateInfrastructureConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.create_infrastructure_configuration)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#create-infrastructure-configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.create_infrastructure_configuration)
+        [Show boto3-stubs documentation](./client.md#create-infrastructure-configuration)
         """
 
     def delete_component(self, componentBuildVersionArn: str) -> DeleteComponentResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.delete_component)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#delete-component)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.delete_component)
+        [Show boto3-stubs documentation](./client.md#delete-component)
         """
 
     def delete_container_recipe(
         self, containerRecipeArn: str
     ) -> DeleteContainerRecipeResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.delete_container_recipe)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#delete-container-recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.delete_container_recipe)
+        [Show boto3-stubs documentation](./client.md#delete-container-recipe)
         """
 
     def delete_distribution_configuration(
         self, distributionConfigurationArn: str
     ) -> DeleteDistributionConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.delete_distribution_configuration)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#delete-distribution-configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.delete_distribution_configuration)
+        [Show boto3-stubs documentation](./client.md#delete-distribution-configuration)
         """
 
     def delete_image(self, imageBuildVersionArn: str) -> DeleteImageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.delete_image)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#delete-image)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.delete_image)
+        [Show boto3-stubs documentation](./client.md#delete-image)
         """
 
     def delete_image_pipeline(self, imagePipelineArn: str) -> DeleteImagePipelineResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.delete_image_pipeline)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#delete-image-pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.delete_image_pipeline)
+        [Show boto3-stubs documentation](./client.md#delete-image-pipeline)
         """
 
     def delete_image_recipe(self, imageRecipeArn: str) -> DeleteImageRecipeResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.delete_image_recipe)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#delete-image-recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.delete_image_recipe)
+        [Show boto3-stubs documentation](./client.md#delete-image-recipe)
         """
 
     def delete_infrastructure_configuration(
         self, infrastructureConfigurationArn: str
     ) -> DeleteInfrastructureConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.delete_infrastructure_configuration)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#delete-infrastructure-configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.delete_infrastructure_configuration)
+        [Show boto3-stubs documentation](./client.md#delete-infrastructure-configuration)
         """
 
     def generate_presigned_url(
@@ -324,80 +324,80 @@ class ImagebuilderClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
         """
 
     def get_component(self, componentBuildVersionArn: str) -> GetComponentResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.get_component)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get-component)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.get_component)
+        [Show boto3-stubs documentation](./client.md#get-component)
         """
 
     def get_component_policy(self, componentArn: str) -> GetComponentPolicyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.get_component_policy)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get-component-policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.get_component_policy)
+        [Show boto3-stubs documentation](./client.md#get-component-policy)
         """
 
     def get_container_recipe(self, containerRecipeArn: str) -> GetContainerRecipeResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.get_container_recipe)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get-container-recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.get_container_recipe)
+        [Show boto3-stubs documentation](./client.md#get-container-recipe)
         """
 
     def get_container_recipe_policy(
         self, containerRecipeArn: str
     ) -> GetContainerRecipePolicyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.get_container_recipe_policy)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get-container-recipe-policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.get_container_recipe_policy)
+        [Show boto3-stubs documentation](./client.md#get-container-recipe-policy)
         """
 
     def get_distribution_configuration(
         self, distributionConfigurationArn: str
     ) -> GetDistributionConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.get_distribution_configuration)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get-distribution-configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.get_distribution_configuration)
+        [Show boto3-stubs documentation](./client.md#get-distribution-configuration)
         """
 
     def get_image(self, imageBuildVersionArn: str) -> GetImageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.get_image)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get-image)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.get_image)
+        [Show boto3-stubs documentation](./client.md#get-image)
         """
 
     def get_image_pipeline(self, imagePipelineArn: str) -> GetImagePipelineResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.get_image_pipeline)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get-image-pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.get_image_pipeline)
+        [Show boto3-stubs documentation](./client.md#get-image-pipeline)
         """
 
     def get_image_policy(self, imageArn: str) -> GetImagePolicyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.get_image_policy)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get-image-policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.get_image_policy)
+        [Show boto3-stubs documentation](./client.md#get-image-policy)
         """
 
     def get_image_recipe(self, imageRecipeArn: str) -> GetImageRecipeResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.get_image_recipe)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get-image-recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.get_image_recipe)
+        [Show boto3-stubs documentation](./client.md#get-image-recipe)
         """
 
     def get_image_recipe_policy(self, imageRecipeArn: str) -> GetImageRecipePolicyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.get_image_recipe_policy)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get-image-recipe-policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.get_image_recipe_policy)
+        [Show boto3-stubs documentation](./client.md#get-image-recipe-policy)
         """
 
     def get_infrastructure_configuration(
         self, infrastructureConfigurationArn: str
     ) -> GetInfrastructureConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.get_infrastructure_configuration)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get-infrastructure-configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.get_infrastructure_configuration)
+        [Show boto3-stubs documentation](./client.md#get-infrastructure-configuration)
         """
 
     def import_component(
@@ -416,16 +416,16 @@ class ImagebuilderClient:
         tags: Dict[str, str] = None,
     ) -> ImportComponentResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.import_component)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#import-component)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.import_component)
+        [Show boto3-stubs documentation](./client.md#import-component)
         """
 
     def list_component_build_versions(
         self, componentVersionArn: str, maxResults: int = None, nextToken: str = None
     ) -> ListComponentBuildVersionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.list_component_build_versions)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list-component-build-versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.list_component_build_versions)
+        [Show boto3-stubs documentation](./client.md#list-component-build-versions)
         """
 
     def list_components(
@@ -437,8 +437,8 @@ class ImagebuilderClient:
         nextToken: str = None,
     ) -> ListComponentsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.list_components)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list-components)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.list_components)
+        [Show boto3-stubs documentation](./client.md#list-components)
         """
 
     def list_container_recipes(
@@ -449,16 +449,16 @@ class ImagebuilderClient:
         nextToken: str = None,
     ) -> ListContainerRecipesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.list_container_recipes)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list-container-recipes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.list_container_recipes)
+        [Show boto3-stubs documentation](./client.md#list-container-recipes)
         """
 
     def list_distribution_configurations(
         self, filters: List[FilterTypeDef] = None, maxResults: int = None, nextToken: str = None
     ) -> ListDistributionConfigurationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.list_distribution_configurations)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list-distribution-configurations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.list_distribution_configurations)
+        [Show boto3-stubs documentation](./client.md#list-distribution-configurations)
         """
 
     def list_image_build_versions(
@@ -469,16 +469,16 @@ class ImagebuilderClient:
         nextToken: str = None,
     ) -> ListImageBuildVersionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.list_image_build_versions)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list-image-build-versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.list_image_build_versions)
+        [Show boto3-stubs documentation](./client.md#list-image-build-versions)
         """
 
     def list_image_packages(
         self, imageBuildVersionArn: str, maxResults: int = None, nextToken: str = None
     ) -> ListImagePackagesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.list_image_packages)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list-image-packages)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.list_image_packages)
+        [Show boto3-stubs documentation](./client.md#list-image-packages)
         """
 
     def list_image_pipeline_images(
@@ -489,16 +489,16 @@ class ImagebuilderClient:
         nextToken: str = None,
     ) -> ListImagePipelineImagesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.list_image_pipeline_images)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list-image-pipeline-images)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.list_image_pipeline_images)
+        [Show boto3-stubs documentation](./client.md#list-image-pipeline-images)
         """
 
     def list_image_pipelines(
         self, filters: List[FilterTypeDef] = None, maxResults: int = None, nextToken: str = None
     ) -> ListImagePipelinesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.list_image_pipelines)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list-image-pipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.list_image_pipelines)
+        [Show boto3-stubs documentation](./client.md#list-image-pipelines)
         """
 
     def list_image_recipes(
@@ -509,8 +509,8 @@ class ImagebuilderClient:
         nextToken: str = None,
     ) -> ListImageRecipesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.list_image_recipes)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list-image-recipes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.list_image_recipes)
+        [Show boto3-stubs documentation](./client.md#list-image-recipes)
         """
 
     def list_images(
@@ -523,72 +523,72 @@ class ImagebuilderClient:
         includeDeprecated: bool = None,
     ) -> ListImagesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.list_images)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list-images)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.list_images)
+        [Show boto3-stubs documentation](./client.md#list-images)
         """
 
     def list_infrastructure_configurations(
         self, filters: List[FilterTypeDef] = None, maxResults: int = None, nextToken: str = None
     ) -> ListInfrastructureConfigurationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.list_infrastructure_configurations)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list-infrastructure-configurations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.list_infrastructure_configurations)
+        [Show boto3-stubs documentation](./client.md#list-infrastructure-configurations)
         """
 
     def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.list_tags_for_resource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list-tags-for-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.list_tags_for_resource)
+        [Show boto3-stubs documentation](./client.md#list-tags-for-resource)
         """
 
     def put_component_policy(
         self, componentArn: str, policy: str
     ) -> PutComponentPolicyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.put_component_policy)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#put-component-policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.put_component_policy)
+        [Show boto3-stubs documentation](./client.md#put-component-policy)
         """
 
     def put_container_recipe_policy(
         self, containerRecipeArn: str, policy: str
     ) -> PutContainerRecipePolicyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.put_container_recipe_policy)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#put-container-recipe-policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.put_container_recipe_policy)
+        [Show boto3-stubs documentation](./client.md#put-container-recipe-policy)
         """
 
     def put_image_policy(self, imageArn: str, policy: str) -> PutImagePolicyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.put_image_policy)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#put-image-policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.put_image_policy)
+        [Show boto3-stubs documentation](./client.md#put-image-policy)
         """
 
     def put_image_recipe_policy(
         self, imageRecipeArn: str, policy: str
     ) -> PutImageRecipePolicyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.put_image_recipe_policy)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#put-image-recipe-policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.put_image_recipe_policy)
+        [Show boto3-stubs documentation](./client.md#put-image-recipe-policy)
         """
 
     def start_image_pipeline_execution(
         self, imagePipelineArn: str, clientToken: str
     ) -> StartImagePipelineExecutionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.start_image_pipeline_execution)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#start-image-pipeline-execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.start_image_pipeline_execution)
+        [Show boto3-stubs documentation](./client.md#start-image-pipeline-execution)
         """
 
     def tag_resource(self, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.tag_resource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#tag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.tag_resource)
+        [Show boto3-stubs documentation](./client.md#tag-resource)
         """
 
     def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.untag_resource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#untag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.untag_resource)
+        [Show boto3-stubs documentation](./client.md#untag-resource)
         """
 
     def update_distribution_configuration(
@@ -599,8 +599,8 @@ class ImagebuilderClient:
         description: str = None,
     ) -> UpdateDistributionConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.update_distribution_configuration)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#update-distribution-configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.update_distribution_configuration)
+        [Show boto3-stubs documentation](./client.md#update-distribution-configuration)
         """
 
     def update_image_pipeline(
@@ -618,8 +618,8 @@ class ImagebuilderClient:
         status: PipelineStatus = None,
     ) -> UpdateImagePipelineResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.update_image_pipeline)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#update-image-pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.update_image_pipeline)
+        [Show boto3-stubs documentation](./client.md#update-image-pipeline)
         """
 
     def update_infrastructure_configuration(
@@ -638,6 +638,6 @@ class ImagebuilderClient:
         resourceTags: Dict[str, str] = None,
     ) -> UpdateInfrastructureConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/imagebuilder.html#Imagebuilder.Client.update_infrastructure_configuration)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#update-infrastructure-configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/imagebuilder.html#Imagebuilder.Client.update_infrastructure_configuration)
+        [Show boto3-stubs documentation](./client.md#update-infrastructure-configuration)
         """
